SystemOrganization addCategory: #GODTextIO!

Object subclass: #TXTIOConverter
	instanceVariableNames: 'types'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIO'!

!TXTIOConverter commentStamp: 'jlcg 10/17/2014 18:29' prior: 0!
Text input and output interface with GOD.!

!TXTIOConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 21:56'!
getFileTypeFromPath: aPath
	"get type (String) of the file from path"

	| char extStream pathStream |

	extStream := WriteStream on: String new.
	pathStream := ReadStream on: aPath.
	char := ''.

	[ (pathStream atEnd) not & (char = $.) not ]
		whileTrue: [ char := pathStream next. ].

	[ pathStream atEnd ]
		whileFalse: [ char := pathStream next.
					 ( char = $. ) ifTrue: [ extStream := WriteStream on: String new. ]
					                   ifFalse: [ extStream nextPut: char ].
				     ].

	^extStream contents.! !

!TXTIOConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 21:13'!
getPossiblesTypes
	"get the possibles types to processing"

	^ types keys.! !

!TXTIOConverter methodsFor: 'initialize-release' stamp: 'jlcg 10/16/2014 12:19'!
initialize
	"set the types dictionary"

	types := Dictionary new.

	types at: #doc put: TXTDocConverter;
                at: #odf put: TXTOdfConverter;
		    at: #pdf put: TXTPdfConverter;
		    at: #txt  put: TXTTextConverter.! !

!TXTIOConverter methodsFor: 'file reading' stamp: 'jlcg 10/17/2014 21:02'!
readFromFile: aPath
	"Read a file from path and converts its contents to a GODData object. Try to extract the file type from the path."

	| fileType |

	fileType := self getFileTypeFromPath: aPath.

	^ self readFromFile: aPath type: fileType.! !

!TXTIOConverter methodsFor: 'file reading' stamp: 'jlcg 10/17/2014 21:02'!
readFromFile: aPath type: fileType
	"Read a file of a given type from path and converts its contents to a GODData object."

	| converter godData |

	( types includesKey: fileType )
		ifFalse: [ GODTextIOInvalidFileType signal ].

	converter := (types at: fileType) new.
	converter path: aPath.
	converter readFile.

	godData := GODData new.
	godData timestamp: TimeStamp now.
	godData origin: 'text'.
	godData content: converter contents.

	^godData.
! !

!TXTIOConverter methodsFor: 'file writing' stamp: 'jlcg 10/17/2014 21:03'!
write: godData toFile: aPath
	"Write a GODData object contents to a file. Try to extract the file type from its path."

	| fileType |

	fileType := self getFileTypeFromPath: aPath.

	^ self write: godData toFile: aPath type: fileType append: false overwrite: false.! !

!TXTIOConverter methodsFor: 'file writing' stamp: 'jlcg 10/17/2014 21:11'!
write: godData toFile: aPath type: fileType
	"Write a GODData object contents to a file of a given type."

	^ self write: godData toFile: aPath type: fileType append: false overwrite: false.! !

!TXTIOConverter methodsFor: 'file writing' stamp: 'jlcg 10/17/2014 21:11'!
write: godData toFile: aPath type: fileType append: aBoolean
	"Write a GODData object contents to a file of a given type. Append determines whether to append contents to an existing file on the given path."

	^ self write: godData toFile: aPath type: fileType append: aBoolean overwrite: false.! !

!TXTIOConverter methodsFor: 'file writing' stamp: 'jlcg 10/17/2014 21:11'!
write: godData toFile: aPath type: fileType append: appendBoolean overwrite: overwriteBoolean
	"Write contents of GODData object to a file."

	| converter |

	( types includesKey: fileType )
		ifFalse: [ GODTextIOInvalidFileType signal ].

	converter := (types at: fileType) new.
	converter append: appendBoolean.
	converter contents: godData content.
	converter overwrite: overwriteBoolean.
	converter path: aPath.

	converter writeFile.

	^ true.! !

!TXTIOConverter methodsFor: 'file writing' stamp: 'jlcg 10/17/2014 21:12'!
write: godData toFile: aPath type: fileType overwrite: aBoolean
	"Write a GODData object contents to a file of a given type. Overwrite determines whether to overwrite or not an existing file of the same name in the given path."

	^ self write: godData toFile: aPath type: fileType append: false overwrite: aBoolean.! !

Object subclass: #TXTMainConverter
	instanceVariableNames: 'append contents overwrite path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIO'!

!TXTMainConverter commentStamp: 'jlcg 10/16/2014 11:27' prior: 0!
The main class of this module. It is an abstract class that models the main methods of the subclasses.!

TXTMainConverter subclass: #TXTDocConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIO'!

!TXTDocConverter commentStamp: 'jlcg 9/27/2014 08:34' prior: 0!
This class process .doc files. The development of this class is secondary.!

!TXTDocConverter methodsFor: 'file processing' stamp: 'jlcg 10/16/2014 11:20'!
readFile
	"Read contents of a DOC file in 'path' to 'content'."

	^true.! !

!TXTDocConverter methodsFor: 'file processing' stamp: 'jlcg 10/16/2014 11:20'!
writeFile
	"Write 'content' to a DOC file in path 'path'."

	^true.! !

!TXTMainConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 18:45'!
append
	^ append.! !

!TXTMainConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 18:45'!
append: aBoolean

	append := aBoolean.
! !

!TXTMainConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 18:45'!
contents
	^ contents! !

!TXTMainConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 18:46'!
contents: aString
	contents := aString.! !

!TXTMainConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 18:46'!
overwrite
	^ overwrite! !

!TXTMainConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 18:46'!
overwrite: aBoolean
	overwrite := aBoolean.! !

!TXTMainConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 18:46'!
path
	^ path.! !

!TXTMainConverter methodsFor: 'accessing' stamp: 'jlcg 10/17/2014 18:47'!
path: aString
	path := aString.! !

!TXTMainConverter methodsFor: 'file processing' stamp: 'mso 10/7/2014 21:36'!
readFile
	"abstract method"

	^ self subclassResponsibility! !

!TXTMainConverter methodsFor: 'file processing' stamp: 'mso 10/7/2014 21:37'!
writeFile
	"abstract method"

	^ self subclassResponsibility! !

TXTMainConverter subclass: #TXTOdfConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIO'!

!TXTOdfConverter commentStamp: 'jlcg 9/27/2014 08:34' prior: 0!
This class process ODF files. The development of this class is secondary.!

!TXTOdfConverter methodsFor: 'file processing' stamp: 'jlcg 10/16/2014 11:20'!
readFile
	"Read contents of a ODF file in 'path' to 'content'."

	^true.! !

!TXTOdfConverter methodsFor: 'file processing' stamp: 'jlcg 10/16/2014 11:21'!
writeFile
	"Write 'content' to an ODF file in path 'path'."

	^true.! !

TXTMainConverter subclass: #TXTPdfConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIO'!

!TXTPdfConverter commentStamp: 'jlcg 9/27/2014 08:34' prior: 0!
This class process PDF files. The development of this class is secondary.!

!TXTPdfConverter methodsFor: 'file processing' stamp: 'jlcg 10/16/2014 11:21'!
readFile
	"Read contents of a PDF file in 'path' to 'content'."

	^true.! !

!TXTPdfConverter methodsFor: 'file processing' stamp: 'jlcg 10/16/2014 11:21'!
writeFile
	"Write 'content' to a PDF file in path 'path'."

	^true.! !

TXTMainConverter subclass: #TXTTextConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIO'!

!TXTTextConverter commentStamp: 'jlcg 9/27/2014 08:33' prior: 0!
This class process text files. The development of this class is prioritary.!

!TXTTextConverter methodsFor: 'file processing' stamp: 'jlcg 10/17/2014 20:45'!
readFile
	"Read contents to a text file in 'path' to 'content'."

	| file |

	file := [ FileStream readOnlyFileNamed: path ] on: FileStreamException do: [ :exception | GODTextIOFileDoesNotExist signal ].

	contents := file contents.

	file close.

	^true.! !

!TXTTextConverter methodsFor: 'file processing' stamp: 'jlcg 10/17/2014 20:46'!
writeFile
	"Write 'content' to a text file in path 'path'."

	| file |

	( overwrite )
		ifTrue: [ file := [ FileStream forceNewFileNamed: path ] 
							on: Error do: [ :exception | exception signal ] ]
		ifFalse: [ ( append )
					ifTrue: [ file := [ FileStream oldFileNamed: path ]
										on: FileDoesNotExistException do: [ :exception | GODTextIOFileDoesNotExist signal ].
							 file setToEnd ; cr. ]
					ifFalse: [ file := [ FileStream newFileNamed: path ]
										on: FileExistsException do: [ :exception | GODTextIOFileAlreadyExists signal ]
										on: Error do: [ :exception | exception signal ] ] ].
	file nextPutAll: contents.
	file close.

	^true.! !
